% Compare measured DPCD preamp TFs with LISO model
%
% ZK, 11/4/2013
%
%%%%%%

%% Load data

% == DATA ==

% Measurement frequency vector
f = 0;

% DCPD 1 TF
mag1 = 0; % [dB]
phi1 = 0; % [deg]

% DCPD 2 TF
mag2 = 0; % [dB]
phi2 = 0; % [deg]


% == LISO ==

load DCPD_TF_liso.mat;
lisomag = interp1(fm,lisomag,f);
lisophi = interp1(fm,lisophi,f);


%% Plot

% Magnitude ratios and phase differences
magrat1 = 10*(mag1-lisomag) + 25;
magrat2 = 10*(mag2-lisomag) + 25;
phidiff1 = 20*(phi1-lisophi);
phidiff2 = 20*(phi2-lisophi);

subplot(2,1,1);
semilogx(f,lisomag,f,mag1,'.',f,mag2,'.',f,magrat1,f,magrat2,'LineWidth',2);
grid on;
ylabel('Magnitude [dB]','FontSize',16);
leg = legend('LISO','Data S/N XXX','Data S/N YYY','Ratio S/N XXX','Ratio S/N YYY','Location','NorthWest');
set(leg,'FontSize',10);
set(gca,'FontSize',14);
axis([f(1) f(end) 0 50]);

ax(1) = gca;
set(ax(1),'XTick',[1e-1 1 1e1 1e2 1e3 1e4 1e5]);
ax(2) = axes('Position', get(ax(1),'Position') ...
             ,'YAxisLocation', 'right' ...
             ,'XAxisLocation', 'top' ...
             ,'Color', 'none' ...
             ,'YColor', 'k' ...
             ,'YScale', 'linear' ...
             ,'XScale', 'log' ...
             ,'XTickLabel', [] ...
             );
linkaxes(ax,'x');
ylim(ax(2),(ylim(ax(1))-25)/10)
set(get(ax(2),'YLabel'),'String','Ratio [dB]','FontSize',16);

title('DCPD in-vac preamp TF vs. LISO','FontSize',20);


subplot(2,1,2);
semilogx(f,lisophi,f,phi1,'.',f,phi2,'.',f,phidiff1,f,phidiff2,'LineWidth',2);
grid on;
xlabel('Frequency [Hz]','FontSize',16);
ylabel('Phase [deg]','FontSize',16);
set(gca,'FontSize',14);
axis([f(1) f(end) -200 200]);
set(gca,'YTick',-180:45:180);

ax(1) = gca;
set(ax(1),'XTick',[1e-1 1 1e1 1e2 1e3 1e4 1e5]);
ax(2) = axes('Position', get(ax(1),'Position') ...
             ,'YAxisLocation', 'right' ...
             ,'XAxisLocation', 'top' ...
             ,'Color', 'none' ...
             ,'YColor', 'k' ...
             ,'YScale', 'linear' ...
             ,'XScale', 'log' ...
             ,'XTickLabel', [] ...
             );
linkaxes(ax,'x');
ylim(ax(2),(ylim(ax(1))/18))
set(get(ax(2),'YLabel'),'String','Phase difference [deg]','FontSize',16);


