% Plot DCPD preamp noise compared to LISO
%
% ZK, 11/4/2013
%
%%%%%%%%%%%%%%%%%

%% Load measured data

% Measurement frequency vector
f = 0;

% DCPD output noise measurements [V/rtHz]
dcpd1_100 = 0; % DCPD 1, Z = 100
dcpd1_400 = 0; % DCPD 1, Z = 400
dcpd2_100 = 0; % DCPD 2, Z = 100
dcpd2_400 = 0; % DCPD 2, Z = 400

% Analyzer output noise measurement [V/rtHz]
an = 0;

%% Load model data and interpolate

load DCPD_noise_liso.mat;

tf100 = interp1(fm,tf100,f);
tf400 = interp1(fm,tf400,f);
nliso100 = interp1(fm,nliso100,f);
nliso400 = interp1(fm,nliso400,f);

%% Process

% Shot noise
Idc = 35e-3; % DC photocurrent (Pc = 50 mW);
Ish = sqrt(2 * 1.602e-19 * Idc) * ones(length(f),1);

% input-refer measured data
nin1_100 = abs(dcpd1_100./tf100);
nin1_400 = abs(dcpd1_400./tf400);
nin2_100 = abs(dcpd2_100./tf100);
nin2_400 = abs(dcpd2_400./tf400);
an100 = abs(an./tf100);
an400 = abs(an./tf400);

loglog(f,nin1_100,'b--',f,nin2_100,'g--',f,nliso100,'r--',f,an100,'k--',f,nin1_400,'b',f,nin2_400,'g',f,nliso400,'r',f,an400,'k',f,Ish,'m','LineWidth',2);
grid on;
set(gca,'FontSize',14);
axis([5e-2 1e5 1e-12 1e-8]);
set(gca,'XTick',[1e-1 1e0 1e1 1e2 1e3 1e4 1e5]);
xlabel('Frequency [Hz]','FontSize',16);
ylabel('Input-referred current noise [A/rtHz]','FontSize',16);
l = legend('DCPD1 (100 ohm)','DCPD2 (100 ohm)','LISO prediction (100 ohm)','Analyzer noise (100 ohm)','DCPD1 (400 ohm)','DCPD2 (400 ohm)','LISO prediction (400 ohm)','Analyzer noise (400 ohm)','Shot noise (I_{DC} = 35 mA)');
set(l,'FontSize',10);
title('eLIGO DCPD dark noise','FontSize',20);

