clear 
clc;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% TF data For preamp #008                                
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ID = '008';
MEASDATE = '2013/06/06';
MEASDATE = '2015/05/16';

% Values of the transimpedance resisters
zL = 100.69; % Ohm
zH = 399.88; % Ohm

% TF Data
% d = importdata('./data_L1/mag8.TXT');
% freqTFA = d(:,1);
% absTFA = 10.^(d(:,2)/20);
% 
% d = importdata('./data_L1/phi8.TXT');
% phsTFA = d(:,2);

d = importdata('./dmass_data_L1/Preamp008.bod');
freqTFA = d(:,1);
absTFA = d(:,2);
phsTFA = d(:,3);

% Spectrum Data
d = importdata('./data_L1/outnoise8.TXT');
freqSPE_L = d(:,1);
freqSPE_H = d(:,1);
absSPE_L  = d(:,2);
absSPE_H  = d(:,3);

d = importdata('./data_L1/analyzer_noise.TXT');
freqSPE_N = d(:,1);
absSPE_N  = d(:,2);

%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%
%% Transimpedance plots
%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%

%% Fig 1 (Linearity) not computed for L1 PDs -- OMITTED

%% Fig 2: Comparison with LISO circuit model (by Zach)

% Compare measured DPCD preamp TFs with LISO model
%
% ZK, 11/4/2013
%
%%%%%%

%% Load data

% == DATA ==

% Measurement frequency vector
f = freqTFA;

% DCPD 1 TF
mag1 = absTFA; % [ratio]
phi1 = phsTFA; % [phase_deg]

% == LISO ==

load('./DCPD_characterization_L1_Zach/DCPD_TF_liso.mat');
lisomag = interp1(fm,10.^(lisomag/20),f);
lisophi = interp1(fm,lisophi,f);


%% Plot

% Magnitude ratios and phase differences
magrat1 = (mag1./lisomag);
phidiff1 = (phi1-lisophi);

figure(2);
clf;
orient landscape;
subplot(4,1,[1 2])
loglog(f, mag1,'bo');
hold on;
loglog(f, lisomag,'r-','LineWidth',2);
grid on;
xlim([.1 1e5]);
ylim([.1 300]);
xlabel('Frequency [Hz]');
ylabel('Voltage Transferfunction [V/V]');
hlegend=legend(...
    'measured',...
    'liso circuit model (circuit param: nominal)',...
    'Location','SouthEast');
title(['\bfPreamp #' ID ' / Circuit model consistency check (' MEASDATE ')'],'FontSize',18);

subplot(4,1,3);
semilogx(f, phi1, 'bo');
hold on;
semilogx(f, lisophi,'r-','LineWidth',2);
grid on;
xlim([.1 1e5]);
ylim([-180 180]);
set(gca, 'Ytick',[-180 -120 -60 0 60 120 180]);
ylabel('Phase [deg]');

subplot(4,1,4);
[ax,h1,h2]=plotyy(f, magrat1, f, phidiff1,'semilogx');
grid on;
xlim([.1 1e5]);
ylim(ax(1),[.8 1.2]);
title('\bfResidual');
ylabel(ax(1),'Ratio');
set(ax(1), 'Ytick',[0.8:0.1:1.2]);
xlabel('Frequency [Hz]');

ylim(ax(2),[-6 6]);
ylabel(ax(2),'Phase Diff [deg]');
set(ax(2), 'Ytick',[-6:3:6]);

print(['./figures/Preamp' ID '_vs_liso_circuit_model.pdf'],'-dpdf','-r600');

%% Fig 3: LISO emprical model

tmp = importdata(['./LISO/TF' ID 'A.out']);
tmp_source = importdata(['./LISO/TF' ID 'A.fil'],'#');
tmp_out = importdata(['./LISO/TF' ID 'A.out'],'#');

tmp_out = {};
fid = fopen(['./LISO/TF' ID 'A.out']);

while ~feof(fid)  
    tmp_out = [tmp_out; fgetl(fid)];
end
fclose(fid);

for ii=1:length(tmp_out)   
    if strfind(tmp_out{ii},'#Best')>0
        istart=ii;
    end
    if strfind(tmp_out{ii},'#Final chi')>0
        iend=ii-2;
    end
end

param_estimation = tmp_out(istart:iend);

%%

freqTF_LISO = tmp.data(:,1);
absTF_LISO = 10.^(tmp.data(:,2)/20);
phsTF_LISO = tmp.data(:,3);

absTF_LISO2   = interp1(freqTF_LISO, absTF_LISO, freqTFA);
phsTF_LISO2 = interp1(freqTF_LISO, phsTF_LISO, freqTFA);

%% Plot

% Magnitude ratios and phase differences
absTF_rat    = (absTFA./absTF_LISO2);
phsTF_diff = (phsTFA-phsTF_LISO2);

figure(3);
clf;

subplot(4,5,[4 5 9 10 14 15 19 20])
rectangle('Position', [0.08 0 1 1], 'FaceColor', 'w');
%title('LISO source','FontSize',10);
text(0.1, 0.99, ...
    [
    '\bf#LISO SOURCE\rm'; ...
    tmp_source; ...
    ' ';...
    ' ';...
    ' ';...
    '\bf===========================';...
    ' ';...
    ' ';...
    ' ';...
    '\bf#Parameter Estimation\rm';...
    ' ';...
    param_estimation...
    ],...
    'VerticalAlignment','top',...
    'FontSize',6);
axis off;
hold on;


subplot(4,5,[1 2 3 6 7 8])
loglog(freqTFA, absTFA, 'bo');
hold on;
loglog(freqTF_LISO, absTF_LISO, 'r-','LineWidth',2);
grid on;
xlim([.1 1e5]);
ylim([1 300]);
ylabel('Transfer function [V/V]');
hlegend=legend(...
    'measured',...
    'LISO empirical fit',...
    'Location','SouthEast');
title(['\bfPreamp #' ID ' / LISO empirical ZPK fit (' MEASDATE ')'],'FontSize',18);
xlabel('Frequency [Hz]');

subplot(4,5,[11 12 13])
semilogx(freqTFA, phsTFA, 'bo');
hold on;
semilogx(freqTF_LISO, phsTF_LISO, 'r-','LineWidth',2);
grid on;
xlim([0.1 1e5]);
ylim([-180 180]);
set(gca, 'Ytick',[-180 -120 -60 0 60 120 180]);
ylabel('Phase [deg]');

subplot(4,5,[16 17 18])
[ax,h1,h2]=plotyy(freqTFA, absTF_rat, freqTFA, phsTF_diff,'semilogx');
grid on;
xlim(ax(1),[.1 1e5]);
ylim(ax(1),[.98 1.02]);
title('\bfResidual');
ylabel(ax(1),'Ratio');
set(ax(1), 'Ytick',[0.98:0.01:1.02]);
xlabel('Frequency [Hz]');

xlim(ax(2),[.1 1e5]);
ylim(ax(2),[-1 1]);
ylabel(ax(2),'Phase Diff [deg]');
set(ax(2), 'Ytick',[-1:0.5:1]);

orient landscape;
print(['./figures/Preamp' ID '_vs_liso_empirical_ZPKfit.pdf'],'-dpdf','-r600');

%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%
%% Power spectra plots
%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%

figure(100);
clf;
loglog(freqSPE_H, absSPE_H, 'r');
hold on;
loglog(freqSPE_L, absSPE_L,'k');
loglog(freqSPE_N, absSPE_N,'g');
ylim([1e-9,1e-5]);
xlim([0.03, 1e5]);

% Plot DCPD preamp noise compared to LISO
%
% ZK, 11/4/2013
%
%%%%%%%%%%%%%%%%%

%% Load measured data

% Measurement frequency vector
f = freqSPE_L;

% DCPD output noise measurements [V/rtHz]
dcpd1_100 = absSPE_L; % DCPD 1, Z = 100
dcpd1_400 = absSPE_H; % DCPD 1, Z = 400

% Analyzer output noise measurement [V/rtHz]
an = absSPE_N;

%% Load model data and interpolate

load('./DCPD_characterization_L1_Zach/DCPD_noise_liso.mat');

tf100 = interp1(freqTF_LISO, absTF_LISO,f)*zL;
tf400 = interp1(freqTF_LISO, absTF_LISO,f)*zH;
nliso100 = interp1(fm, nliso100, f);
nliso400 = interp1(fm, nliso400, f);

%% Process

% Shot noise
Idc = 35e-3; % DC photocurrent (Pc = 50 mW);
Ish = sqrt(2 * 1.602e-19 * Idc) * ones(length(f),1);

% input-refer measured data
nin1_100 = abs(dcpd1_100./tf100);
nin1_400 = abs(dcpd1_400./tf400);
an100 = abs(an./tf100);
an400 = abs(an./tf400);

figure(4);
clf;
orient landscape;

loglog(f, nin1_100, 'b--');
hold on;
loglog(f, nliso100, 'r--', 'LineWidth',2);
loglog(f, an100,    'k--');
loglog(f, nin1_400, 'b');
loglog(f, nliso400, 'r',   'LineWidth',2);
loglog(f, an400,    'k');
loglog(f, Ish,      'm',   'LineWidth',2);
grid on;
ylabel('Current noise [A/rtHz]');
xlabel('Frequency [Hz]');
ylim([1e-12,1e-8]);
xlim([0.03, 1e5]);
set(gca,'XTick', 10.^[-2:5]);
title(['\bfPreamp #' ID ' / Input-referred Current noise (' MEASDATE ')'],'FontSize',18);
l = legend(...
    'DCPD (100 ohm)',...
    'LISO prediction (100 ohm)',...
    'Analyzer noise (100 ohm)', ...
    'DCPD (400 ohm)',...
    'LISO prediction (400 ohm)',...
    'Analyzer noise (400 ohm)',...
    'Shot noise (I_{DC} = 35 mA)'...
);
print(['./figures/Preamp' ID '_current_noise.pdf'],'-dpdf','-r600');


